﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using System.ComponentModel;
using System.Windows.Media.Imaging;
using System.Windows.Markup;

namespace WindowsPhoneTest
{
    public partial class MainPage : PhoneApplicationPage
    {
        /// <summary>
        /// Size of the pages
        /// </summary>
        public const int PageWidth = 400;

        public MainPage()
        {
            this.PageList = new List<UserControl>() 
                { 
                    new WindowsPhoneControl1() { IsEnabled = false }, 
                    new WindowsPhoneControl2() { IsEnabled = false }, 
                    new WindowsPhoneControl3() { IsEnabled = false } 
                };

            this.CurrentPageIndex = 0;

            InitializeComponent();

            SupportedOrientations = SupportedPageOrientation.Portrait;
        }

        /// <summary>
        /// Ordered list of the panorama pages
        /// </summary>
        protected List<UserControl> PageList { get; set; }

        /// <summary>
        /// Index of the page currently displayed
        /// </summary>
        protected int CurrentPageIndex { get; set; }

        private void PhoneApplicationPage_Loaded(object sender, RoutedEventArgs e)
        {
            var frame = (PhoneApplicationFrame)Application.Current.RootVisual;
            frame.Width = PageWidth * 3;

            var title = new PanoramicTitle();

            this.TitlePanel.Children.Add(title);

            this.LoadPages();
        }

        private void LoadPages()
        {
            this.PanoramicGrid.Children.Clear();

            var currentPage = this.PageList[this.CurrentPageIndex];
            currentPage.IsEnabled = true;

            this.PanoramicGrid.Children.Add(currentPage);
            Grid.SetColumn(currentPage, 1);
            Grid.SetRow(currentPage, 1);

            if (this.PageList.Count > this.CurrentPageIndex + 1)
            {
                var nextPage = this.PageList[this.CurrentPageIndex + 1];
                nextPage.IsEnabled = false;

                this.PanoramicGrid.Children.Add(nextPage);

                Grid.SetColumn(nextPage, 2);
                Grid.SetRow(nextPage, 1);
            }

            if (this.CurrentPageIndex > 0)
            {
                var previousPage = this.PageList[this.CurrentPageIndex - 1];
                previousPage.IsEnabled = false;

                this.PanoramicGrid.Children.Add(previousPage);

                Grid.SetColumn(previousPage, 0);
                Grid.SetRow(previousPage, 1);
            }
        }

        private void PhoneApplicationPage_ManipulationCompleted(object sender, ManipulationCompletedEventArgs e)
        {
            if (e.OriginalSource is Panel)
            {
                if (e.TotalManipulation.Translation.X < 0)
                {
                    if (e.TotalManipulation.Translation.X > -180 || this.CurrentPageIndex >= this.PageList.Count - 1)
                    {
                        this.SlideTitleDoubleAnimation.To = this.CurrentPageIndex * PageWidth / 2 * -1;
                        this.PageChangeAnimation.Begin();
                    }
                    else
                    {
                        this.ChangePage(1);
                    }
                }
                else if (e.TotalManipulation.Translation.X > 0)
                {
                    if (e.TotalManipulation.Translation.X < 180 || this.CurrentPageIndex <= 0)
                    {
                        this.SlideTitleDoubleAnimation.To = this.CurrentPageIndex * PageWidth / 2 * -1;
                        this.PageChangeAnimation.Begin();
                    }
                    else
                    {
                        this.ChangePage(-1);
                    }
                }
            }
        }

        private void ChangePage(int step)
        {
            this.CurrentPageIndex += step;

            this.LoadPages();

            this.PanoramaContentTranslate.X += PageWidth * step;

            this.SlideTitleDoubleAnimation.To = this.CurrentPageIndex * PageWidth / 2 * -1;

            this.PageChangeAnimation.Begin();
        }

        private void PhoneApplicationPage_ManipulationDelta(object sender, ManipulationDeltaEventArgs e)
        {
            if (e.OriginalSource is Panel)
            {
                this.PanoramaContentTranslate.X = e.CumulativeManipulation.Translation.X - PageWidth;

                this.TitleTranslate.X = e.CumulativeManipulation.Translation.X /2 - (this.CurrentPageIndex * PageWidth / 2);
            }
        }
    }
}